@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025  Dimas Firmansyah
 
 ;; Author: Dimas Firmansyah <deirn@bai.lol>
-;; Package-Version: 20251024.1621
-;; Package-Revision: f13e555c8074
+;; Package-Version: 20251117.1738
+;; Package-Revision: 27c86dc00096
 ;; Homepage: https://github.com/deirn/mason.el
 ;; Package-Requires: ((emacs "30.1") (s "1.13.0"))
 ;; Keywords: tools lsp installer
@@ -45,7 +45,8 @@
 
 (defcustom mason-registry-refresh-time (* 60 60 24 7)
   "How long in seconds before trying to refresh the registry.
-Defaults to 1 week."
+Defaults to 1 week.  Set to 0 or less to disable automatic refresh.
+This value is checked on every `mason-ensure' call."
   :type 'integer :group 'mason)
 
 (defcustom mason-registries
@@ -1265,7 +1266,7 @@ Call CALLBACK if it succeeded."
     (if (null reg-time)
         (mason-update-registry callback)
       (setq reg-age (float-time (time-subtract (current-time) reg-time)))
-      (if (> reg-age mason-registry-refresh-time)
+      (if (and (> mason-registry-refresh-time 0) (> reg-age mason-registry-refresh-time))
           (mason-update-registry callback)
         (mason--update-target
          (lambda ()
